import React, { useState, useEffect } from 'react'
import Head from 'next/head'

import LoadingIndicator from '../components/LoadingIndicator.js'
import QuestionSearchResult from '../components/QuestionSearchResult.js'

import styles from './allQuestions.module.css'

export default function AllQuestions({ router, getData }) {
  const [data, setData] = useState(null)
  const [searchTerm, setSearchTerm] = useState('')

  useEffect(() => {
    getData().then((result) => {
      setData(result)

      router.replace(`${router.asPath.replace('.html', '')}`, undefined, {
        shallow: true,
      })
      const querySearch = router.query.question
        ? decodeURIComponent(router.query.question)
        : ''
      setSearchTerm(querySearch)
    })
  }, [])

  return (
    <div>
      <Head>
        <title>Qmining - Kérdés keresés | Frylabs.net</title>
      </Head>
      {data ? (
        <>
          <div className={styles.searchContainer}>
            <input
              autoFocus
              placeholder="Keresés..."
              className={styles.searchBar}
              type="text"
              value={searchTerm}
              onChange={(e) => {
                setSearchTerm(e.target.value)
                router.replace(
                  `${router.pathname}${e.target.value &&
                    '?question='}${encodeURIComponent(e.target.value)}`,
                  undefined,
                  { shallow: true }
                )
              }}
            />
            <button
              onClick={() => {
                setSearchTerm('')
              }}
              className={styles.clearButton}
            >
              X
            </button>
          </div>
          <hr />
          <div>
            <QuestionSearchResult data={data} searchTerm={searchTerm} />
          </div>
        </>
      ) : (
        <LoadingIndicator />
      )}
    </div>
  )
}
